import requests

import vdcpy.config as config


def get_files(
    file_id=None, name=None, created_by=None, format=None, visibility=None,
    work=None):
    """
    Get a list of files from the VDC API.

    Parameters
    ----------
    file_id : str
        The ID of the file to retrieve.
    name : str
        The name of the file to retrieve.
    created_by : str
        The email address of the user who created the file.
    format : str
        The format of the file to retrieve.
    visibility : str
        The visibility of the file to retrieve.
    work : str
        The ID of the work to which the file belongs.
    
    Returns
    -------
    file_list : list
        A list of files.
    """
    project_list = []
    query = f'{config.API_URL}/{config.FILE_NAMESPACE}'
    if file_id is not None:
        query += f'?id={file_id}'
    if name is not None:
        if file_id is None:
            query += f'?name={name}'
        else:
            query += f'&name={name}'
    if created_by is not None:
        if file_id is None and name is None:
            query += f'?created_by={created_by}'
        else:
            query += f'&created_by={created_by}'
    if format is not None:
        if file_id is None and name is None and created_by is None:
            query += f'?format={format}'
        else:
            query += f'&format={format}'
    if visibility is not None:
        if file_id is None and name is None and created_by is None \
            and format is None:
            query += f'?visibility={visibility}'
        else:
            query += f'&visibility={visibility}'
    if work is not None:
        if file_id is None and name is None and created_by is None \
            and format is None and visibility is None:
            query += f'?work={work}'
        else:
            query += f'&work={work}'
    response = requests.get(query)
    if response.status_code == 200:
        project_list = response.json()
    else:
        raise Exception(f'Error getting projects: {response.status_code}')
    return project_list


def add_file(work_id, file_path):
    """
    Add a file to a work.

    Parameters
    ----------
    work_id : str
        The ID of the work to which the file should be added.
    file_path : str
        The path to the file to be added.
    """
    query = f'{config.API_URL}/{config.FILE_NAMESPACE}/{work_id}'
    # Get filename from file_path
    if '/' in file_path:
        filename = file_path.split('/')[-1]
    else:
        filename = file_path.split('\\')[-1]
    # Post with requests the query and the file
    with open(file_path, 'rb') as file:
        response = requests.post(query, files={'file': (filename, file)})
    if response.status_code != 201:

        raise Exception(f'Error adding file: {response.status_code}')
    return response.json()


def delete_file(file_id):
    """
    Delete a file from the VDC API.

    Parameters
    ----------
    file_id : str
        The ID of the file to delete.
    """
    query = f'{config.API_URL}/{config.FILE_NAMESPACE}/{file_id}'
    response = requests.delete(query)
    if response.status_code != 204:
        raise Exception(f'Error deleting file: {response.status_code}')
