import requests

import vdcpy.config as config


def get_users(
    user_id=None, name=None, email=None, organization=None, position=None):
    """
    Get a list of users from the VDC API.

    Parameters
    ----------
    user_id : str
        The user ID of the user to get.
    name : str
        The name of the user to get.
    email : str
        The email of the user to get.
    organization : str
        The organization of the user to get.
    position : str
        The position of the user to get.

    Returns
    -------
    user_list : list
        A list of users.
    """
    user_list = []
    query = f'{config.API_URL}/{config.USER_NAMESPACE}'
    if user_id is not None:
        query += f'?id={user_id}'
    if name is not None:
        if user_id is None:
            query += f'?name={name}'
        else:
            query += f'&name={name}'
    if email is not None:
        if user_id is None and name is None:
            query += f'?email={email}'
        else:
            query += f'&email={email}'
    if organization is not None:
        if user_id is None and name is None and email is None:
            query += f'?organization={organization}'
        else:
            query += f'&organization={organization}'
    if position is not None:
        if user_id is None and name is None and email is None and \
            organization is None:
            query += f'?position={position}'
        else:
            query += f'&position={position}'
    response = requests.get(query)
    if response.status_code == 200:
        user_list = response.json()
    else:
        raise Exception(f'Error getting users: {response.status_code}')
    return user_list


def add_user(user_info):
    """
    Add a user to the VDC API.

    Parameters
    ----------
    user_info : dict
        The user information to add.
    """
    query = f'{config.API_URL}/{config.USER_NAMESPACE}'
    response = requests.post(query, json=user_info)
    if response.status_code == 201:
        return response.json()
    else:
        raise Exception(
            f'Error adding user: {response.status_code} - {response.json()}'
        )


def delete_user(user_id):
    """
    Delete a user from the VDC API.

    Parameters
    ----------
    user_id : str
        The user ID of the user to delete.
    """
    query = f'{config.API_URL}/{config.USER_NAMESPACE}/{user_id}'
    response = requests.delete(query)
    if response.status_code == 204:
        return True
    else:
        raise Exception(
            f'Error deleting user: {response.status_code} - {response.json()}'
        )


def update_user(user_id, user_info):
    """
    Update a user in the VDC API.

    Parameters
    ----------
    user_id : str
        The user ID of the user to update.
    user_info : dict
        The user information to update.
    """
    query = f'{config.API_URL}/{config.USER_NAMESPACE}/{user_id}'
    response = requests.put(query, json=user_info)
    if response.status_code == 200:
        return response.json()
    else:
        raise Exception(
            f'Error updating user: {response.status_code} - {response.json()}'
        )
